mathics: A general-purpose computer algebra system
==================================================

Description
-----------

A general-purpose computer algebra system.

License
-------

GPL

Upstream Contact
----------------

https://pypi.org/project/Mathics3/

